@@ -11,7 +11,7 @@ use Encode::Locale qw(decode_argv);
 
 
 use 5.008_005;
-our $VERSION = '5.18.0.1.30';
+our $VERSION = '5.18.0.1.31';
 
 our @EXPORT = qw(print_pod print_pods);
 
@@ -190,21 +190,35 @@ C<<prepare_encoding_console>> - Получает кодировку консол
 
 =head1 AUTHOR
 
-  Nikolay Mishin E<lt>mi@ya.ruE<gt>
+Nikolay Mishin E<lt>mi@ya.ruE<gt>
 
 =head1 CONTRIBUTORS
 
-  Анатолий Шарифулин  C<< <sharifulin@gmail.com> >>
-  Алексей Суриков C<< <KSURi> >>
-  Михаил Любимов  C<< <mikhail.lyubimov> >>
-  Дмитрий Константинов  C<< <Dim_K> >>
-  Евгений Баранов  C<< <Baranov> >>
-  Антон Николаев C<< <me@lelf.lu> >>
-  Динар Жамалиев C<< <zhdinar> >>
-  Валерий Кравчук C<< <valera@openxs.kiev.ua> >>
-  Enrique Nell 
-  Yusuke Kawasaki
-  Вячеслав Тихановский (VTI)
+=over
+
+=item * Анатолий Шарифулин  C<< <sharifulin@gmail.com> >>
+
+=item * Алексей Суриков C<< <KSURi> >>
+
+=item * Михаил Любимов  C<< <mikhail.lyubimov> >>
+
+=item * Дмитрий Константинов  C<< <Dim_K> >>
+
+=item * Евгений Баранов  C<< <Baranov> >>
+
+=item * Антон Николаев C<< <me@lelf.lu> >>
+
+=item * Динар Жамалиев C<< <zhdinar> >>
+
+=item * Валерий Кравчук C<< <valera@openxs.kiev.ua> >>
+
+=item * Enrique Nell 
+
+=item * Yusuke Kawasaki
+
+=item * Вячеслав Тихановский (VTI)
+
+=back
 
 =head1 COPYRIGHT
 
